@@ -1,3 +1,6 @@
+from pkgutil import extend_path
+__path__ = extend_path(__path__, __name__)
+
 import abc
 import builtins
 import datetime
@@ -13,7 +16,7 @@ from typeguard import check_type
 import aws_cdk.cloud_assembly_schema._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@aws-cdk/cx-api", "2.112.0", __name__[0:-6], "cx-api@2.112.0.jsii.tgz"
+    "@aws-cdk/cx-api", "2.138.0", __name__[0:-6], "cx-api@2.138.0.jsii.tgz"
 )
 
 __all__ = [
